clear
close all

cd D:\MATLAB\work\GSK

% Kopriva_Jeric_SCA_JMS_vol_44_9_2009

% Pure components

load PC1_fill.txt     % pure component
mz = PC1_fill(:,1)';
S(1,:) = PC1_fill(:,2)';

load PC2_fill.txt     % pure component
S(2,:) = PC2_fill(:,2)';

load PC3_fill.txt     % pure component
S(3,:) = PC3_fill(:,2)';

load PC4_fill.txt     % pure component
S(4,:) = PC4_fill(:,2)';

load PC5_fill.txt     % pure component
S(5,:) = PC5_fill(:,2)';

for n=1:5
    figure
    mm = max(S(n,:));
    S(n,:)=100*S(n,:)/mm;
    plot(mz,S(n,:),'k')
    xlabel('m/z')
    ylabel('Relative abundance')
    title(strcat('PC',num2str(n)))
end

load X2M1_fil.txt
load X2M3_fil.txt

mz=X2M1_fil(:,1)';

X(1,:)=X2M1_fil(:,2)';
X(2,:)=X2M3_fil(:,2)';

T = length(mz);
[N TL]=size(X);

figure
mm = max(X(1,:));
X1n=100*X(1,:)/mm;
plot(mz,X1n,'k')
%grid
xlabel('m/z')
ylabel('Relative abundance')
axis([100 700 0 100])
title('X1')

figure
mm = max(X(2,:));
X2n=100*X(2,:)/mm;
plot(mz,X2n,'k')
%grid
xlabel('m/z')
ylabel('Relative abundance')
axis([100 700 0 100])
title('X2')

% estimate number of pure components and matrix of concentration profiles through data clustering

dfi=0.1;                % mixing angle grid
sigma = 0.06;           % dispersition factor in spectrum function
eps_ratio = 20;         % to eliminate components around origin
chain_order = 7;        % order of the peak detection chain
AH = clustering_1_average_dominant_Babieh_Jutten(X(:,1:TL),eps_ratio,sigma,dfi,chain_order);

% estimate pure components through linear programming
[N M] = size(AH);
f = ones(M,1); 
lb = zeros(M,1);
ub = 1e6*ones(M,1);

tic
g = waitbar(0,'Please wait...');
for m=1:TL
    cxm=X(:,m);
    [sh,fval,exitflag,output]=linprog(f,[],[],AH,cxm,lb,ub,[],optimset('Display','iter'));    % solves linear program min(x) f'*x s.t. Ax=b, lb<=x<=ub.
    SH(:,m) = sh;
    waitbar(m/TL,g)
end
close(g);
toc

for n=1:M
    figure
    mm = max(SH(n,:));
    SH(n,:)=100*SH(n,:)/mm;
    plot(mz,SH(n,:),'k')
    title(strcat('SH',num2str(n)))
    xlabel('m/z')
    ylabel('Relative abundance')
    amin = min(SH(n,:)); amax=max(SH(n,:));
    axis([100 700 amin amax])
end

% calculate correlation coefficients with true pure components
XC(:,1)= PC1_fill(:,2);
XC(:,2)= PC2_fill(:,2);
XC(:,3)= PC3_fill(:,2);
XC(:,4)= PC4_fill(:,2);
XC(:,5)= PC5_fill(:,2);

for i=1:M
    XX(:,1)=SH(i,:);
    for j=1:M
        XX(:,2)=XC(:,j);
        crf=corrcoef(XX);
        crpcsh(i,j)=abs(crf(1,2));
    end
end

display('Correlation coefficients between true and estimated pure components')
for m=1:M
    max(crpcsh(:,m))
end



