
%
% Estimation of the column vectors the 2xM parameterized basis matrix
% 
% For 1- average dominant problem accoridng to cluster assignment is based on the
% paper: F.M. Naini, et. al, Neurocomputing 71 (2008) 2330-2343.
%

function [AH]= clustering_1_average_dominant_Babieh_Jutten(X,eps_ratio,sigma,dfi,chain_order)


% INPUTS:
% X - 2xT data matrix in sparse representation
%
% eps_ratio - treshold w.r.t. largest components to eliminate small
% samples, i.e. if 1/norm(x(t)) > eps_ratio, x(t) is not taken into
% account.
%
% sigma - dispertion parameter for calculating function to detect
% concentration subspaces
%
% dfi - grid resolution (in degrees) in calculating mixing vector angles
% chain_order - order of the peak detector. MUST BE an odd number.

%
% OUTPUT:
% AH - estimate of the 2xM parameterized basis matrix 
%

[N T] = size(X);
%if (N > 2)
 %   display('Number of measurements must be 2 for this algorithm')
 %   return
%end

sigma2 = 2*sigma*sigma;

% initiaize peak detector
if (rem(chain_order,2) == 0)
    chain_order = chain_order + 1;
end
chain = zeros(1,chain_order)';
mid=round(chain_order/2);
chain(mid)=-0.1;

g = waitbar(0,'Looking for maximum...');

for t=1:T
    Xn(1,t)=norm(X(:,t));
    waitbar(t/T,g)
end
close(g);
[xmax indmax] = max(Xn);  
X = X/xmax;

g = waitbar(0,'Eliminating small components...');
n=0;
for t=1:T
    if(1/norm(X(:,t)) < eps_ratio)
        n=n+1;
        XR(:,n)=X(:,t);
    end
    waitbar(t/T,g)
end
close(g)


clear X
T = n;
X=XR;
clear XR
g = waitbar(0,'Normalization...');
for t=1:T
    X(:,t)=X(:,t)/norm(X(:,t));
    waitbar(t/T,g)
end
close(g)

hh= waitbar(0,'Clustering - please wait...');

dfi = pi*dfi/180;

nfi=0;
for fi=0:dfi:pi/2
    nfi = nfi+1;
    f(nfi)=0;
    b=[cos(fi) sin(fi)];
    for t=1:T
        x=X(:,t);
        d2=1-(b*x).^2;
        f(nfi)=f(nfi) + exp(-d2/sigma2);
    end
    waitbar(fi/(pi/2),hh)
end

close(hh)

fi=0:dfi:pi/2;

figure
plot(fi*180/pi,f,'k')
grid
xlabel('angle [degrees]')

M=0;
for i=1:length(f)
    chain(1)=f(i);
    [fm indm]=max(chain);
    if indm == mid
       M=M+1;
       ang(M)=fi(i-mid+1);
    end
    chain=circshift(chain,1);
end

ang*180/pi

for m=1:M
    AH(:,m)=[cos(ang(m)) sin(ang(m))]';
end

AH


%pause


